@@ -7,13 +7,15 @@ from matplotlib.ticker import FuncFormatter, MultipleLocator, FixedLocator
 
 from mpl_format.axes.ticks_formatter import TicksFormatter
 from mpl_format.compound_types import FontSize, StringMapper
+from mpl_format.literals import ROTATION_MODE, AXIS_SCALE, WHICH_AXIS
 from mpl_format.text.text_formatter import TextFormatter
 from mpl_format.text.text_list_formatter import TextListFormatter
+from mpl_format.utils.number_utils import format_as_integer
 
 
 class AxisFormatter(object):
 
-    def __init__(self, axis: Axis, direction: str, axes: Axes):
+    def __init__(self, axis: Axis, direction: WHICH_AXIS, axes: Axes):
         """
         Create a new AxisFormatter
 
@@ -120,7 +122,8 @@ class AxisFormatter(object):
         return self
 
     def rotate_label(
-            self, rotation: int, how: str = 'absolute'
+            self, rotation: int,
+            how: ROTATION_MODE = 'absolute'
     ) -> 'AxisFormatter':
         """
         Set the rotation of the axis label.
@@ -179,21 +182,7 @@ class AxisFormatter(object):
             if t == '':
                 return ''
             number = float(t)
-            if not kmbt:
-                return f'{int(number):,}'
-            else:
-                for power, abbrev in zip(
-                        [12, 9, 6, 3],
-                        ['T', 'B', 'M', 'K']
-                ):
-                    if number >= 10 ** power:
-                        num = number / 10 ** power
-                        if num == int(num):
-                            num = int(num)
-                        return f'{num:,}{abbrev}'
-                if number == int(number):
-                    number = int(number)
-                return f'{number:,}'
+            return format_as_integer(number=number, kmbt=kmbt)
 
         if not categorical:
             tick = FuncFormatter(lambda x, pos: to_integer(x))
@@ -206,7 +195,9 @@ class AxisFormatter(object):
         return self
 
     def set_format_currency(
-            self, symbol: str = '$', num_decimals: int = 0,
+            self,
+            symbol: str = '$',
+            num_decimals: int = 0,
             categorical: bool = False,
             kmbt: bool = False
     ) -> 'AxisFormatter':
@@ -256,9 +247,12 @@ class AxisFormatter(object):
 
         return self
 
-    def set_format_percent(self, num_decimals: int = 0,
-                           multiply_100: bool = True,
-                           categorical: bool = False) -> 'AxisFormatter':
+    def set_format_percent(
+            self,
+            num_decimals: int = 0,
+            multiply_100: bool = True,
+            categorical: bool = False
+    ) -> 'AxisFormatter':
         """
         Format an axis as a percentage.
 
@@ -294,13 +288,16 @@ class AxisFormatter(object):
 
     # region set scale
 
-    def set_scale(self, scale: str) -> 'AxisFormatter':
+    def set_scale(self, scale: AXIS_SCALE) -> 'AxisFormatter':
         """
         Set the scale for the Axis.
 
         :param scale: One of ['log', 'linear', 'symlog', 'logit']
         """
-        self._axis._set_scale(scale)
+        if self._direction == 'x':
+            self._axes.set_xscale(value=scale)
+        else:
+            self._axes.set_yscale(value=scale)
         return self
 
     def set_scale_log(self) -> 'AxisFormatter':
