@@ -7,12 +7,15 @@ from matplotlib.figure import Figure
 from numpy import ndarray, reshape
 from numpy.ma import empty_like
 
+from compound_types.built_ins import Scalar
 from mpl_format.axes import AxisFormatter
 from mpl_format.axes.axes_formatter import AxesFormatter
 from mpl_format.axes.axes_formatter_array import AxesFormatterArray
 from mpl_format.axes.axis_formatter_array import AxisFormatterArray
 from mpl_format.compound_types import StringMapper, Color
 from mpl_format.enums.line_style import LINE_STYLE
+from mpl_format.literals import ROTATION_MODE, WHICH_TICKS, SHARE_AXES, \
+    WHICH_AXIS
 from mpl_format.utils.io_utils import save_plot
 
 TextSetter = TypeVar(
@@ -27,9 +30,9 @@ class FigureFormatter(object):
 
     def __init__(self, fig_or_axes: Union[Figure, Axes] = None,
                  n_rows: int = 1, n_cols: int = 1,
-                 fig_size: Tuple[int, int] = (16, 9),
-                 share_x: str = 'none',
-                 share_y: str = 'none',
+                 fig_size: Tuple[Scalar, Scalar] = (16, 9),
+                 share_x: SHARE_AXES = 'none',
+                 share_y: SHARE_AXES = 'none',
                  constrained_layout: bool = True):
 
         if fig_or_axes is not None:
@@ -65,6 +68,11 @@ class FigureFormatter(object):
                 isinstance(self._axes, ndarray) or isinstance(self._axes, list)
         )
 
+    @staticmethod
+    def gcf() -> 'FigureFormatter':
+
+        return FigureFormatter(fig_or_axes=plt.gcf())
+
     # region properties
 
     @property
@@ -372,9 +380,9 @@ class FigureFormatter(object):
         """
         if self._has_array:
             for axf in self.multi.flat:
-                axf.wrap_x_tick_labels(max_width=max_width)
+                axf.x_ticks.wrap_label_text(max_width=max_width)
         else:
-            self.single.wrap_x_tick_labels(max_width=max_width)
+            self.single.x_ticks.wrap_label_text(max_width=max_width)
         return self
 
     def wrap_y_tick_labels(self, max_width: int) -> 'FigureFormatter':
@@ -386,9 +394,9 @@ class FigureFormatter(object):
         """
         if self._has_array:
             for axf in self.multi.flat:
-                axf.wrap_y_tick_labels(max_width=max_width)
+                axf.y_ticks.wrap_label_text(max_width=max_width)
         else:
-            self.single.wrap_y_tick_labels(max_width=max_width)
+            self.single.y_ticks.wrap_label_text(max_width=max_width)
         return self
 
     def wrap_tick_labels(self, max_width: int) -> 'FigureFormatter':
@@ -461,9 +469,9 @@ class FigureFormatter(object):
         """
         if self._has_array:
             for axf in self.multi.flat:
-                axf.map_x_tick_labels(mapping=mapping)
+                axf.x_ticks.map_label_text(mapping=mapping)
         else:
-            self.single.map_x_tick_labels(mapping=mapping)
+            self.single.x_ticks.map_label_text(mapping=mapping)
         return self
 
     def map_y_tick_labels(
@@ -476,9 +484,9 @@ class FigureFormatter(object):
         """
         if self._has_array:
             for axf in self.multi.flat:
-                axf.map_y_tick_labels(mapping=mapping)
+                axf.y_ticks.map_label_text(mapping=mapping)
         else:
-            self.single.map_y_tick_labels(mapping=mapping)
+            self.single.y_ticks.map_label_text(mapping=mapping)
         return self
 
     def map_tick_labels(
@@ -585,7 +593,7 @@ class FigureFormatter(object):
 
     def rotate_x_labels(self,
                         rotation: int,
-                        how: str = 'absolute') -> 'FigureFormatter':
+                        how: ROTATION_MODE = 'absolute') -> 'FigureFormatter':
         """
         Set the rotation of each x-axis label.
 
@@ -601,7 +609,7 @@ class FigureFormatter(object):
 
     def rotate_y_labels(self,
                         rotation: int,
-                        how: str = 'absolute') -> 'FigureFormatter':
+                        how: ROTATION_MODE = 'absolute') -> 'FigureFormatter':
         """
         Set the rotation of each x-axis label.
 
@@ -616,35 +624,31 @@ class FigureFormatter(object):
         return self
 
     def rotate_x_tick_labels(self,
-                             rotation: int,
-                             how: str = 'absolute') -> 'FigureFormatter':
+                             rotation: int) -> 'FigureFormatter':
         """
         Set the rotation of each x-axis' tick-labels.
 
         :param rotation: The rotation value to set in degrees.
-        :param how: 'absolute' or 'relative'
         """
         if self._has_array:
             for axf in self.multi.flat:
-                axf.rotate_x_tick_labels(rotation=rotation, how=how)
+                axf.x_ticks.set_label_rotation(rotation=rotation)
         else:
-            self.single.rotate_x_tick_labels(rotation=rotation, how=how)
+            self.single.x_ticks.set_label_rotation(rotation=rotation)
         return self
 
     def rotate_y_tick_labels(self,
-                             rotation: int,
-                             how: str = 'absolute') -> 'FigureFormatter':
+                             rotation: int) -> 'FigureFormatter':
         """
         Set the rotation of each y-axis' tick-labels.
 
         :param rotation: The rotation value to set in degrees.
-        :param how: 'absolute' or 'relative'
         """
         if self._has_array:
             for axf in self.multi.flat:
-                axf.rotate_y_tick_labels(rotation=rotation, how=how)
+                axf.y_ticks.set_label_rotation(rotation=rotation)
         else:
-            self.single.rotate_y_tick_labels(rotation=rotation, how=how)
+            self.single.y_ticks.set_label_rotation(rotation=rotation)
         return self
 
     # endregion
@@ -768,8 +772,8 @@ class FigureFormatter(object):
 
     def grids(
             self, value: bool = True,
-            which: str = 'major',
-            axis: str = 'both',
+            which: WHICH_TICKS = 'major',
+            axis: WHICH_AXIS = 'both',
             color: Optional[Color] = None,
             line_width: Optional[float] = None,
             line_style: Optional[Union[str, LINE_STYLE]] = None
